// VotingScreen.jsx
import { useState, useEffect } from 'react';
import { useGame } from '../context/GameContext';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faVoteYea, faTrophy, faMusic } from '@fortawesome/free-solid-svg-icons';
import YouTubeEmbed from './YouTubeEmbed';

function VotingScreen() {
  const { lobby, currentPlayer, submitVote } = useGame();
  const [hasVoted, setHasVoted] = useState(false);
  const [selectedSong, setSelectedSong] = useState(null);
  const [countdown, setCountdown] = useState(null);

  // Get current battle
  const battle = lobby?.currentBattle || null;

  // Check if player has already voted
  useEffect(() => {
    if (battle && battle.votes && currentPlayer) {
      // Check if player's ID exists in votes map
      setHasVoted(battle.votes.has(currentPlayer.id));
    } else {
      setHasVoted(false);
    }
  }, [battle, currentPlayer]);

  // Handle vote selection
  const handleVoteSelect = (songId) => {
    if (hasVoted) return;
    
    setSelectedSong(songId);
  };

  // Submit final vote
  const handleSubmitVote = () => {
    if (!selectedSong || hasVoted) return;
    
    submitVote(selectedSong);
    setHasVoted(true);
  };

  // Get YouTube video IDs from links
  const getYouTubeId = (url) => {
    if (!url) return null;
    
    const regExp = /^.*(youtu.be\/|v\/|u\/\w\/|embed\/|watch\?v=|&v=)([^#&?]*).*/;
    const match = url.match(regExp);
    
    return (match && match[2].length === 11) ? match[2] : null;
  };

  if (!battle || !battle.song1 || !battle.song2) {
    return (
      <div className="voting-screen">
        <h2>Preparing the next battle...</h2>
      </div>
    );
  }

  const song1Id = getYouTubeId(battle.song1?.youtubeLink || '');
  const song2Id = getYouTubeId(battle.song2?.youtubeLink || '');

  return (
    <div className="voting-screen">
      <header className="voting-header">
        <h1>
          <FontAwesomeIcon icon={faVoteYea} /> Song Battle!
        </h1>
        <div className="round-info">
          <span>Round {battle.round + 1}</span>
          {hasVoted && <span className="voted-badge">You voted!</span>}
        </div>
      </header>
      
      <div className="battle-container">
        <div 
          className={`song-card ${selectedSong === battle.song1.id ? 'selected' : ''} ${hasVoted ? 'voted' : ''}`}
          onClick={() => handleVoteSelect(battle.song1.id)}
        >
          <div className="song-spotlight"></div>
          <div className="song-details">
            <h3>{battle.song1.title}</h3>
            <p>{battle.song1.artist}</p>
            <div className="song-submitter">
              <small>Submitted by: {battle.song1.submittedByName}</small>
            </div>
          </div>
          
          {song1Id ? (
            <div className="video-container">
              <YouTubeEmbed videoId={song1Id} />
              <div className="video-overlay"></div>
            </div>
          ) : (
            <div className="no-video">
              <FontAwesomeIcon icon={faMusic} className="pulse-icon" />
              <span>No video available</span>
            </div>
          )}
          
          {hasVoted && (
            <div className="vote-count">
              <span className="vote-number">{battle.song1Votes}</span>
              <span className="vote-text">votes</span>
            </div>
          )}
          
          {selectedSong === battle.song1.id && !hasVoted && (
            <div className="selection-indicator">
              <FontAwesomeIcon icon={faCheck} className="check-icon" />
            </div>
          )}
        </div>
        
        <div className="versus">
          <span className="versus-text">VS</span>
          <div className="versus-decoration"></div>
        </div>
        
        <div 
          className={`song-card ${selectedSong === battle.song2.id ? 'selected' : ''} ${hasVoted ? 'voted' : ''}`}
          onClick={() => handleVoteSelect(battle.song2.id)}
        >
          <div className="song-spotlight"></div>
          <div className="song-details">
            <h3>{battle.song2.title}</h3>
            <p>{battle.song2.artist}</p>
            <div className="song-submitter">
              <small>Submitted by: {battle.song2.submittedByName}</small>
            </div>
          </div>
          
          {song2Id ? (
            <div className="video-container">
              <YouTubeEmbed videoId={song2Id} />
              <div className="video-overlay"></div>
            </div>
          ) : (
            <div className="no-video">
              <FontAwesomeIcon icon={faMusic} className="pulse-icon" />
              <span>No video available</span>
            </div>
          )}
          
          {hasVoted && (
            <div className="vote-count">
              <span className="vote-number">{battle.song2Votes}</span>
              <span className="vote-text">votes</span>
            </div>
          )}
          
          {selectedSong === battle.song2.id && !hasVoted && (
            <div className="selection-indicator">
              <FontAwesomeIcon icon={faCheck} className="check-icon" />
            </div>
          )}
        </div>
      </div>
      
      {!hasVoted && (
        <div className="voting-actions">
          <button 
            className="btn primary" 
            onClick={handleSubmitVote}
            disabled={!selectedSong}
          >
            Cast Vote
          </button>
        </div>
      )}
      
      <div className="voting-status">
        <p>{hasVoted ? 'Waiting for other players to vote...' : 'Choose your favorite!'}</p>
        <div className="votes-count">
          <span>{battle.voteCount || 0}</span> of <span>{lobby?.players?.filter(p => p.isConnected).length || 0}</span> votes
        </div>
      </div>
    </div>
  );
}

export default VotingScreen;
